@@ -227,11 +227,11 @@ package Sidef::Exec {
                 my @arguments;
                 my $method = $call->{method};
 
-                if (ref $method eq 'HASH') {
+                if (ref($method) eq 'HASH') {
                     $method = $self->execute_expr($method) // '';
                 }
 
-                if (ref $method eq 'Sidef::Variable::Variable') {
+                if (ref($method) eq 'Sidef::Variable::Variable') {
                     $method = $method->get_value;
                 }
 
@@ -249,7 +249,7 @@ package Sidef::Exec {
                 if ($type eq 'Sidef::Variable::Variable') {
                     my $value = $self_obj->get_value;
                     $type = ref($value);
-                    if (   $type eq 'Sidef::Module::Caller'
+                    if (   $type eq 'Sidef::Module::OO'
                         or $type eq 'Sidef::Module::Func') {
                         $self_obj = $value;
                     }
