@@ -50,10 +50,11 @@ package Sidef::Types::Hash::Hash {
         my %hash;
         while (my ($k, $v) = each %{$self->{data}}) {
             my $rv = $v->get_value;
-            $hash{$k} =
-              (ref($rv) && defined eval { $rv->can('get_value') })
-              ? $rv->get_value
-              : $rv;
+            $hash{$k} = (
+                         ref($rv) =~ /^Sidef::/
+                         ? $rv->get_value
+                         : $rv
+                        );
         }
 
         \%hash;
@@ -318,10 +319,7 @@ package Sidef::Types::Hash::Hash {
     }
 
     *pairs    = \&to_a;
-    *toArray  = \&to_a;
     *to_array = \&to_a;
-    *to_pairs = \&to_a;
-    *toPairs  = \&to_a;
 
     sub exists {
         my ($self, $key) = @_;
